@@ -1,4 +1,4 @@
-# $Id: DocutilsTestSupport.py 6320 2010-05-07 08:16:56Z milde $
+# $Id: DocutilsTestSupport.py 7539 2012-11-26 13:50:06Z milde $
 # Authors: David Goodger <goodger@python.org>;
 #          Garth Kidd <garth@deadlybloodyserious.com>
 # Copyright: This module has been placed in the public domain.
@@ -9,7 +9,7 @@ Exports the following:
 :Modules:
     - `statemachine` is 'docutils.statemachine'
     - `nodes` is 'docutils.nodes'
-    - `urischemes` is 'docutils.urischemes'
+    - `urischemes` is 'docutils.utils.urischemes'
     - `utils` is 'docutils.utils'
     - `transforms` is 'docutils.transforms'
     - `states` is 'docutils.parsers.rst.states'
@@ -50,16 +50,23 @@ from pprint import pformat
 
 testroot = os.path.abspath(os.path.dirname(__file__) or os.curdir)
 os.chdir(testroot)
-sys.path.insert(0, os.path.normpath(os.path.join(testroot, '..')))
+if sys.version_info >= (3,0):
+    sys.path.insert(0, os.path.normpath(os.path.join(testroot,
+                                                     '..', 'build', 'lib')))
+    sys.path.append(os.path.normpath(os.path.join(testroot, '..',
+                                                  'build', 'lib', 'extras')))
+else:
+    sys.path.insert(0, os.path.normpath(os.path.join(testroot, '..')))
+    sys.path.append(os.path.normpath(os.path.join(testroot, '..', 'extras')))
 sys.path.insert(0, testroot)
-sys.path.append(os.path.normpath(os.path.join(testroot, '..', 'extras')))
 
 try:
     import difflib
     import package_unittest
     import docutils
     import docutils.core
-    from docutils import frontend, nodes, statemachine, urischemes, utils
+    from docutils import frontend, nodes, statemachine, utils
+    from docutils.utils import urischemes
     from docutils.transforms import universal
     from docutils.parsers import rst
     from docutils.parsers.rst import states, tableparser, roles, languages
@@ -107,35 +114,47 @@ class StandardTestCase(unittest.TestCase):
     def setUp(self):
         os.chdir(testroot)
 
-    def failUnlessEqual(self, first, second, msg=None):
+    def assertEqual(self, first, second, msg=None):
         """Fail if the two objects are unequal as determined by the '=='
            operator.
         """
         if not first == second:
-            raise self.failureException, \
-                  (msg or '%s != %s' % _format_str(first, second))
+            raise self.failureException, (
+                    msg or '%s != %s' % _format_str(first, second))
 
-    def failIfEqual(self, first, second, msg=None):
+    def assertNotEqual(self, first, second, msg=None):
         """Fail if the two objects are equal as determined by the '=='
            operator.
         """
         if first == second:
-            raise self.failureException, \
-                  (msg or '%s == %s' % _format_str(first, second))
+            raise self.failureException, (
+                    msg or '%s == %s' % _format_str(first, second))
 
-    # Synonyms for assertion methods
+    # assertIn and assertNotIn: new in Python 2.7:
 
-    assertEqual = assertEquals = failUnlessEqual
+    def assertIn(self, a, b, msg=None):
+        if a not in b:
+            raise self.failureException, (
+                    msg or '%s not in %s' % _format_str(a, b))
 
-    assertNotEqual = assertNotEquals = failIfEqual
+    def assertNotIn(self, a, b, msg=None):
+        if a in b:
+            raise self.failureException, (
+                    msg or '%s in %s' % _format_str(a, b))
+
+    # aliases for assertion methods, deprecated since Python 2.7
+
+    failUnlessEqual = assertEquals = assertEqual
+
+    assertNotEquals = failIfEqual = assertNotEqual
 
 
 class CustomTestCase(StandardTestCase):
-    
+
     """
     Helper class, providing extended functionality over unittest.TestCase.
 
-    The methods failUnlessEqual and failIfEqual have been overwritten
+    The methods assertEqual and assertNotEqual have been overwritten
     to provide better support for multi-line strings.  Furthermore,
     see the compare_output method and the parameter list of __init__.
     """
@@ -143,8 +162,8 @@ class CustomTestCase(StandardTestCase):
     compare = difflib.Differ().compare
     """Comparison method shared by all subclasses."""
 
-    def __init__(self, method_name, input, expected, id, run_in_debugger=0,
-                 suite_settings=None):
+    def __init__(self, method_name, input, expected, id,
+                 run_in_debugger=True, suite_settings=None):
         """
         Initialise the CustomTestCase.
 
@@ -162,7 +181,7 @@ class CustomTestCase(StandardTestCase):
         self.expected = expected
         self.run_in_debugger = run_in_debugger
         self.suite_settings = suite_settings.copy() or {}
-        
+
         # Ring your mother.
         unittest.TestCase.__init__(self, method_name)
 
@@ -203,8 +222,13 @@ class CustomTestCase(StandardTestCase):
                 expected = expected.encode('raw_unicode_escape')
             if isinstance(output, unicode):
                 output = output.encode('raw_unicode_escape')
+        # Normalize line endings:
+        if expected:
+            expected = '\n'.join(expected.splitlines())
+        if output:
+            output = '\n'.join(output.splitlines())
         try:
-            self.assertEquals(output, expected)
+            self.assertEqual(output, expected)
         except AssertionError, error:
             print >>sys.stderr, '\n%s\ninput:' % (self,)
             print >>sys.stderr, input
@@ -269,7 +293,7 @@ class CustomTestSuite(unittest.TestSuite):
             self.id = id
 
     def addTestCase(self, test_case_class, method_name, input, expected,
-                    id=None, run_in_debugger=0, **kwargs):
+                    id=None, run_in_debugger=False, **kwargs):
         """
         Create a CustomTestCase in the CustomTestSuite.
         Also return it, just in case.
@@ -400,7 +424,7 @@ class TransformTestSuite(CustomTestSuite):
         for name, (transforms, cases) in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case)==3:
                     # TODO: (maybe) change the 3rd argument to a dict, so it
                     # can handle more cases by keyword ('disable', 'debug',
@@ -408,7 +432,7 @@ class TransformTestSuite(CustomTestSuite):
                     # But there's also the method that
                     # HtmlPublishPartsTestSuite uses <DJG>
                     if case[2]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(
@@ -474,10 +498,10 @@ class ParserTestSuite(CustomTestSuite):
         for name, cases in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case)==3:
                     if case[2]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(
@@ -491,7 +515,7 @@ class PEPParserTestCase(ParserTestCase):
 
     """PEP-specific parser test case."""
 
-    parser = rst.Parser(rfc2822=1, inliner=rst.states.Inliner())
+    parser = rst.Parser(rfc2822=True, inliner=rst.states.Inliner())
     """Parser shared by all PEPParserTestCases."""
 
     option_parser = frontend.OptionParser(components=(rst.Parser, pep.Reader))
@@ -559,10 +583,10 @@ class GridTableParserTestSuite(CustomTestSuite):
         for name, cases in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case) == 4:
                     if case[-1]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(self.test_case_class, 'test_parse_table',
@@ -602,10 +626,10 @@ class SimpleTableParserTestSuite(CustomTestSuite):
         for name, cases in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case) == 3:
                     if case[-1]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(self.test_case_class, 'test_parse',
@@ -663,10 +687,10 @@ class PythonModuleParserTestSuite(CustomTestSuite):
         for name, cases in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case)==3:
                     if case[2]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(
@@ -682,8 +706,8 @@ class WriterPublishTestCase(CustomTestCase, docutils.SettingsSpec):
     Test case for publish.
     """
 
-    settings_default_overrides = {'_disable_config': 1,
-                                  'strict_visitor': 1}
+    settings_default_overrides = {'_disable_config': True,
+                                  'strict_visitor': True}
     writer_name = '' # set in subclasses or constructor
 
     def __init__(self, *args, **kwargs):
@@ -719,10 +743,10 @@ class PublishTestSuite(CustomTestSuite):
         for name, cases in dict.items():
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case)==3:
                     if case[2]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(
@@ -742,10 +766,10 @@ class HtmlPublishPartsTestSuite(CustomTestSuite):
             settings.update(settings_overrides)
             for casenum in range(len(cases)):
                 case = cases[casenum]
-                run_in_debugger = 0
+                run_in_debugger = False
                 if len(case)==3:
                     if case[2]:
-                        run_in_debugger = 1
+                        run_in_debugger = True
                     else:
                         continue
                 self.addTestCase(
@@ -782,7 +806,7 @@ class HtmlWriterPublishPartsTestCase(WriterPublishTestCase):
         # interpolate standard variables:
         expected = self.expected % {'version': docutils.__version__}
         self.compare_output(self.input, output, expected)
-    
+
     standard_content_type_template = ('<meta http-equiv="Content-Type"'
                                       ' content="text/html; charset=%s" />\n')
     standard_generator_template = (
@@ -866,7 +890,7 @@ def _format_str(*args):
     return_tuple = []
     for i in args:
         r = repr(i)
-        if ( (isinstance(i, str) or isinstance(i, unicode))
+        if ( (isinstance(i, bytes) or isinstance(i, unicode))
              and '\n' in i):
             stripped = ''
             if isinstance(i, unicode) and r.startswith('u'):
