@@ -1,7 +1,7 @@
 #!/bin/sh
 ''''exec python -u "$0" "$@" #'''
 
-# $Id: alltests.py 7052 2011-06-05 13:12:06Z grubert $
+# $Id: alltests.py 7433 2012-05-11 21:03:07Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -33,8 +33,13 @@ class Tee:
         self.encoding = getattr(stream, 'encoding', None)
 
     def write(self, string):
-        self.stream.write(string)
-        self.file.write(string)
+        try:
+            self.stream.write(string)
+            self.file.write(string)
+        except UnicodeEncodeError:   # Py3k writing to "ascii" stream/file
+            string = string.encode('raw_unicode_escape').decode('ascii')
+            self.stream.write(string)
+            self.file.write(string)
 
     def flush(self):
         self.stream.flush()
