@@ -4,4 +4,4 @@ settings_overrides['report_level'] = 2
 settings_overrides['halt_level'] = 5
 settings_overrides['warning_stream'] = ''
 settings_overrides['input_encoding'] = 'utf-8'
-settings_overrides['embed_stylesheet'] = 0
+settings_overrides['embed_stylesheet'] = False
