@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: test_language.py 6433 2010-09-28 08:21:25Z milde $
+# $Id: test_language.py 7503 2012-08-26 15:42:37Z grubert $
 # Authors: Engelbert Gruber <grubert@users.sourceforge.net>;
 #          David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
@@ -53,6 +53,11 @@ class LanguageTestSuite(DocutilsTestSupport.CustomTestSuite):
         # test language tag normalization:
         self.languages += ['en_gb', 'en_US', 'en-CA', 'de-DE', 'de-AT-1901',
                            'pt-BR', 'pt-foo-BR']
+        # test that locally created language files are also loaded.
+        # requires local_dummy_lang.py in test directory (testroot)
+        # The local_dummy_lang.py contains all the fields from both
+        # the docutils language tags and the parser.rst language tags
+        self.languages += ['local_dummy_lang']
 
     def generateTests(self):
         for language in self.languages:
