@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_include.py 6314 2010-04-26 10:04:17Z milde $
+# $Id: test_include.py 7514 2012-09-14 14:27:12Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -13,28 +13,32 @@ import sys
 from __init__ import DocutilsTestSupport
 from docutils.parsers.rst import states
 from docutils._compat import b
+from docutils.utils.code_analyzer import with_pygments
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
+    if not with_pygments:
+        del(totest['include-code'])
     s.generateTests(totest)
     return s
 
-mydir = 'test_parsers/test_rst/test_directives/'
-include1 = os.path.join(mydir, 'include1.txt')
-include1rel = DocutilsTestSupport.utils.relative_path(None, include1)
-include2 = os.path.join(mydir, 'include2.txt')
-include3 = os.path.join(mydir, 'include3.txt')
-include8 = os.path.join(mydir, 'include8.txt')
-include10 = os.path.join(mydir, 'include10.txt')
-include10rel = DocutilsTestSupport.utils.relative_path(None, include10)
-include11 = os.path.join(mydir, 'include 11.txt')
-include11rel = DocutilsTestSupport.utils.relative_path(None, include11)
-include12 = os.path.join(mydir, 'include12.txt')
-include13 = os.path.join(mydir, 'include13.txt')
-include13rel = DocutilsTestSupport.utils.relative_path(None, include13)
-include_literal = os.path.join(mydir, 'include_literal.txt')
-utf_16_file = os.path.join(mydir, 'utf-16.csv')
-utf_16_file_rel = DocutilsTestSupport.utils.relative_path(None, utf_16_file)
+# prepend this directory (relative to the test root):
+def mydir(path):
+    return os.path.join('test_parsers/test_rst/test_directives/', path)
+# make `path` relative with utils.relative_path():
+def reldir(path):
+    return DocutilsTestSupport.utils.relative_path(None, path)
+
+include1 = mydir('include1.txt')
+include2 = mydir('include2.txt')
+include3 = mydir('include3.txt')
+include8 = mydir('include8.txt')
+include10 = mydir('include10.txt')
+include11 = mydir('include 11.txt')
+include12 = mydir('include12.txt')
+include13 = mydir('include13.txt')
+include_literal = mydir('include_literal.txt')
+utf_16_file = mydir('utf-16.csv')
 utf_16_error_str = ("UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe "
                     "in position 0: ordinal not in range(128)")
 if sys.version_info < (3,0):
@@ -46,6 +50,18 @@ nonexistent = os.path.join(os.path.dirname(states.__file__),
 nonexistent_rel = DocutilsTestSupport.utils.relative_path(
     os.path.join(DocutilsTestSupport.testroot, 'dummy'), nonexistent)
 
+# Different error for path with 8bit chars with locale == C or None:
+try:
+    open(u'\u043c\u0438\u0440.txt')
+except UnicodeEncodeError:
+    errstr_8bit_path = u"""\
+Cannot encode input file path "\u043c\u0438\u0440.txt" (wrong locale?).\
+"""
+except:
+    errstr_8bit_path = u"""\
+InputError: [Errno 2] No such file or directory: '\u043c\u0438\u0440.txt'.\
+"""
+
 totest = {}
 
 totest['include'] = [
@@ -79,6 +95,8 @@ Include Test
 
 .. include:: %s
    :literal:
+   :class: test
+   :name: my name
 
 A paragraph.
 """ % include1,
@@ -87,14 +105,82 @@ A paragraph.
     <section ids="include-test" names="include\ test">
         <title>
             Include Test
-        <literal_block source="%s" xml:space="preserve">
+        <literal_block classes="test" ids="my-name" names="my\ name" source="%s" xml:space="preserve">
             Inclusion 1
             -----------
             \n\
             This file is used by ``test_include.py``.
         <paragraph>
             A paragraph.
-""" % include1rel],
+""" % reldir(include1)],
+["""\
+Literal include, add line numbers
+
+.. include:: %s
+   :literal:
+   :number-lines:
+""" % include1,
+"""\
+<document source="test data">
+    <paragraph>
+        Literal include, add line numbers
+    <literal_block source="%s" xml:space="preserve">
+        <inline classes="ln">
+            1 \n\
+        Inclusion 1
+        <inline classes="ln">
+            2 \n\
+        -----------
+        <inline classes="ln">
+            3 \n\
+        \n\
+        <inline classes="ln">
+            4 \n\
+        This file is used by ``test_include.py``.
+""" % reldir(include1)],
+["""\
+Include code
+
+.. include:: %s
+   :code:
+   :class: test
+   :name: my name
+""" % include1,
+"""\
+<document source="test data">
+    <paragraph>
+        Include code
+    <literal_block classes="code test" ids="my-name" names="my\ name" source="%s" xml:space="preserve">
+        Inclusion 1
+        -----------
+        \n\
+        This file is used by ``test_include.py``.
+""" % reldir(include1)],
+["""\
+Include code, add line numbers
+
+.. include:: %s
+   :code:
+   :number-lines:
+""" % include1,
+"""\
+<document source="test data">
+    <paragraph>
+        Include code, add line numbers
+    <literal_block classes="code" source="%s" xml:space="preserve">
+        <inline classes="ln">
+            1 \n\
+        Inclusion 1
+        <inline classes="ln">
+            2 \n\
+        -----------
+        <inline classes="ln">
+            3 \n\
+        \n\
+        <inline classes="ln">
+            4 \n\
+        This file is used by ``test_include.py``.
+""" % reldir(include1)],
 ["""\
 Let's test the parse context.
 
@@ -138,7 +224,7 @@ A paragraph.
         <system_message level="4" line="4" source="test data" type="SEVERE">
             <paragraph>
                 Problems with "include" directive path:
-                IOError: [Errno 2] No such file or directory: 'nonexistent.txt'.
+                InputError: [Errno 2] No such file or directory: 'nonexistent.txt'.
             <literal_block xml:space="preserve">
                 .. include:: nonexistent.txt
         <paragraph>
@@ -180,7 +266,7 @@ A paragraph.
                 .
             <paragraph>
                 A paragraph.
-""" % include1rel],
+""" % reldir(include1)],
 ["""\
 Include Test
 ============
@@ -220,7 +306,7 @@ A paragraph.
                 .
             <paragraph>
                 A paragraph.
-""" % include1rel],
+""" % reldir(include1)],
 ["""\
 In test data
 
@@ -298,7 +384,7 @@ Encoding:
 
 .. include:: %s
    :encoding: utf-16
-""" % utf_16_file_rel,
+""" % reldir(utf_16_file),
 b("""\
 <document source="test data">
     <paragraph>
@@ -315,7 +401,7 @@ Include file is UTF-16-encoded, and is not valid ASCII.
 
 .. include:: %s
    :encoding: ascii
-""" % utf_16_file_rel,
+""" % reldir(utf_16_file),
 """\
 <document source="test data">
     <paragraph>
@@ -327,8 +413,23 @@ Include file is UTF-16-encoded, and is not valid ASCII.
         <literal_block xml:space="preserve">
             .. include:: %s
                :encoding: ascii
-""" % (utf_16_error_str, utf_16_file_rel)],
-# @@@ BUG with errors reported with incorrect "source" & "line":
+""" % (utf_16_error_str, reldir(utf_16_file))],
+[u"""\
+cyrillic filename:
+
+.. include:: \u043c\u0438\u0440.txt
+""",
+u"""\
+<document source="test data">
+    <paragraph>
+        cyrillic filename:
+    <system_message level="4" line="3" source="test data" type="SEVERE">
+        <paragraph>
+            Problems with "include" directive path:
+            %s
+        <literal_block xml:space="preserve">
+            .. include:: \u043c\u0438\u0440.txt
+""" % errstr_8bit_path],
 ["""\
 Testing errors in included file:
 
@@ -369,7 +470,7 @@ Testing errors in included file:
         <system_message level="4" line="12" source="%(source)s" type="SEVERE">
             <paragraph>
                 Problems with "include" directive path:
-                IOError: [Errno 2] No such file or directory: '%(nonexistent)s'.
+                InputError: [Errno 2] No such file or directory: '%(nonexistent)s'.
             <literal_block xml:space="preserve">
                 .. include:: <nonexistent>
         <system_message level="3" line="14" source="%(source)s" type="ERROR">
@@ -559,7 +660,7 @@ Testing errors in included file:
                 ==============  ======
                 A simple table  with
                 no bottom       border
-""" % {'source': include10rel, 'nonexistent': nonexistent_rel,
+""" % {'source': reldir(include10), 'nonexistent': reldir(nonexistent),
        'unichr_exception':
        DocutilsTestSupport.exception_data(unichr, int("11111111", 16))[2]
       }],
@@ -567,7 +668,7 @@ Testing errors in included file:
 Include file with whitespace in the path:
 
 .. include:: %s
-""" % include11rel,
+""" % reldir(include11),
 """\
 <document source="test data">
     <paragraph>
@@ -608,7 +709,7 @@ Nonexistent standard include data file:
     <system_message level="4" line="3" source="test data" type="SEVERE">
         <paragraph>
             Problems with "include" directive path:
-            IOError: [Errno 2] No such file or directory: '%s'.
+            InputError: [Errno 2] No such file or directory: '%s'.
         <literal_block xml:space="preserve">
             .. include:: <nonexistent>
 """ % nonexistent_rel],
@@ -800,6 +901,63 @@ No TAB expansion with literal include:
 """ % include_literal],
 ]
 
+totest['include-code'] = [
+["""\
+Included code
+
+.. include:: %s
+   :code: rst
+""" % include1,
+"""\
+<document source="test data">
+    <paragraph>
+        Included code
+    <literal_block classes="code rst" source="%s" xml:space="preserve">
+        <inline classes="generic heading">
+            Inclusion 1
+        \n\
+        <inline classes="generic heading">
+            -----------
+        \n\
+        \n\
+        This file is used by \n\
+        <inline classes="literal string">
+            ``test_include.py``
+        .
+""" % reldir(include1)],
+["""\
+Included code
+
+.. include:: %s
+   :code: rst
+   :number-lines:
+""" % include1,
+"""\
+<document source="test data">
+    <paragraph>
+        Included code
+    <literal_block classes="code rst" source="%s" xml:space="preserve">
+        <inline classes="ln">
+            1 \n\
+        <inline classes="generic heading">
+            Inclusion 1
+        \n\
+        <inline classes="ln">
+            2 \n\
+        <inline classes="generic heading">
+            -----------
+        \n\
+        <inline classes="ln">
+            3 \n\
+        \n\
+        <inline classes="ln">
+            4 \n\
+        This file is used by \n\
+        <inline classes="literal string">
+            ``test_include.py``
+        .
+""" % reldir(include1)],
+]
 
 if __name__ == '__main__':
     import unittest
