@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_replace.py 4667 2006-07-12 21:40:56Z wiemann $
+# $Id: test_replace.py 7021 2011-04-29 23:20:54Z grubert $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -109,10 +109,10 @@ I recommend you try |Python|_.
             Inline literal start-string without end-string.
     <system_message level="3" line="1" source="test data" type="ERROR">
         <paragraph>
-            Error in "replace" directive: may contain a single paragraph only.
-    <system_message level="2" line="1" source="test data" type="WARNING">
-        <paragraph>
-            Substitution definition "name" empty or invalid.
+            Substitution definition contains illegal element:
+        <literal_block xml:space="preserve">
+            <problematic ids="id2" refid="id1">
+                *
         <literal_block xml:space="preserve">
             .. |name| replace::  *error in **inline ``markup
 """],
