@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_role.py 4667 2006-07-12 21:40:56Z wiemann $
+# $Id: test_role.py 6424 2010-09-18 10:43:52Z smerten $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -195,6 +195,20 @@ Testing a :fileref:`role` in a nested parse.
                 role
              in a nested parse.
 """],
+["""\
+.. role:: custom
+.. role:: special
+
+Empty :custom:`\ ` and empty `\ `:special:
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        Empty 
+        <inline classes="custom">
+         and empty 
+        <inline classes="special">
+"""],
 ]
 
 totest['raw_role'] = [
