@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_topics.py 4667 2006-07-12 21:40:56Z wiemann $
+# $Id: test_topics.py 7062 2011-06-30 22:14:29Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -55,6 +55,21 @@ totest['topics'] = [
             Body.
 """],
 ["""\
+.. topic:: With Options
+   :class: custom
+   :name: my point
+
+   Body.
+""",
+"""\
+<document source="test data">
+    <topic classes="custom" ids="my-point" names="my\ point">
+        <title>
+            With Options
+        <paragraph>
+            Body.
+"""],
+["""\
 .. topic::
 
    Title
